aboutsummaryrefslogtreecommitdiff
path: root/src/cli.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/cli.rs')
-rw-r--r--src/cli.rs16
1 files changed, 14 insertions, 2 deletions
diff --git a/src/cli.rs b/src/cli.rs
index 38ac648..61b3d39 100644
--- a/src/cli.rs
+++ b/src/cli.rs
@@ -46,9 +46,21 @@ pub enum Commands {
total: bool
},
- /// Add a new agent to lend or pay
- Add {
+ /// Add, update or remove an agent
+ Agent {
name: String,
+
+ /// Add a new agent (default)
+ #[arg(short,long)]
+ add: bool,
+
+ /// Delete a registered agent
+ #[arg(short,long, conflicts_with_all = ["add", "update"])]
+ delete: bool,
+
+ /// Update a registered agent
+ #[arg(short,long, conflicts_with_all = ["add", "delete"], value_name = "NEW_NAME")]
+ update: Option<String>
},
}
Feel free to download, copy and edit any repo